function [Cn2, ro] = GenerateProfile(filename, parameters, reg);

% Generates pupil plane profile from scintillation covariance data.
%
% Inputs:   filename   - Name of file containing covariance data
%           parameters - A vector containing values for 
%                        [zenith, binary_sep, m_diff, dr, scidar_defocus]
%                        where: zenith         - angle from the vertical (degrees)
%                               binary_sep     - separation of binary star
%                                                components (arcsecs)
%                               m_diff         - magnitude difference of binary
%                                                star components
%                               dr             - pupil plane sampling (m)
%                               scidar_defocus - amount of defocus beneath 
%                                                telescope (km)
%           reg        - regularisation parameter value (between 0 and 1)
%
% Outputs:  Cn2        - Estimated Cn2 profile 
%           ro         - Estimated ro value
%
% Usage: [Cn2, ro] = GenerateProfile('Run1_0_auto', parameters, 0.01);
%
% Rachel Johnston, 23/1/2002


% Performing the pupil plane inversion
[Cn2, Cn2_unscaled, ro, h, Tmod, S] = SCIDARResultsnew(parameters, reg, filename);

% Displaying the results
figure
plot(h(1:size(Cn2,1))-parameters(4)*10^(3),Cn2)
xlabel('altitude (m)')
ylabel('Cn2 (m^{-2/3})')
figure
plot(h(1:size(Cn2,1))-parameters(4)*10^(3),Tmod*Cn2_unscaled)
title('Fit to the data')
hold on
plot(h(1:size(Cn2,1))-parameters(4)*10^(3),S,'r')
xlabel('altitude (m)')
ylabel('covariance')
hold off






