function [Tfull] = genTmat(zenith, binary_sep, r, h, scidar_defocus);
% Generates T matrices required for Cn2h estimation
%
% function [Tfull, Treduced] = genTmat(zenith, binary_sep, dr, scidar_defocus, factor);
%
% Inputs:	zenith 			- zenith angle(degrees)
%				binary_sep		- binary star separation (arcseconds)
%				dr					- pupil scale	(metres pix-1)
%				scidar_defocus	- generalised SCIDAR defocus (km)
%				factor 			- subsampling factor used to generate reduced T matrix
%				
% Outputs:	Tfull				- full T matrix
%				Treduced			- subsampled T matrix
%
% Usage:		[Tfull, Treduced] = genTmat(12.01, 10.3, 1/128, 0, 7);	
%
% Rachel Johnston, 22/4/99 

secz = 1/cos(zenith*pi/180); 		
thi = binary_sep/((3600*180)/pi);
h_max = 25000;
wavelength = 500e-9;		% wavelength (m)

Tfull = tmatrix(zenith, binary_sep, r, h, wavelength);
